@@ -1,12 +1,13 @@
 # -*- coding: utf-8 -*-
-from src.common import registry
+from upddetect.common import registry
 from tabulate import tabulate
-from src.packet_managers.general import PacketManager
-from variables import BColors, __DESC__, __URL__, __AUTHOR__, __VERSION__, __LOGO__, __HELP__
+from upddetect.packet_managers.general import PacketManager
+from upddetect.variables import BColors, __DESC__, __URL__, __AUTHOR__, __VERSION__, __LOGO__, __HELP__
 import sys
 import getopt
 import tqdm
 import json
+import os
 
 
 def print_welcome():
@@ -19,7 +20,9 @@ def print_welcome():
     print()
 
 
-def main(argv):
+def main():
+    argv = sys.argv[1:]
+
     only_security = dist_updates = all_updates = json_output = False
     updates1 = updates2 = []
     opts, args = getopt.getopt(argv, "hvsdaj")
@@ -57,6 +60,7 @@ def main(argv):
         print()
         print(BColors.HEADER + "Scan outdated packages:" + BColors.ENDC)
     packages = []
+    pms = []
     for cls in registry.packet_managers:
         pm_root = cls(colorize=not json_output)
         pm_instances = pm_root.find_all_instances()
@@ -64,13 +68,19 @@ def main(argv):
         progress = tqdm.tqdm(pm_instances, ascii=True, disable=json_output)
         for pm in progress:
             if pm.is_available():
+                real_path = os.path.realpath(pm.get_pm_path())
+                if real_path not in pms:
+                    pms.append(real_path)
+                else:
+                    continue
+
                 progress.set_description("%s" % pm)
                 if not dist_updates or all_updates:
                     p, updates1 = pm.detect_updates(only_security)
                 if dist_updates or all_updates:
                     p, updates2 = pm.detect_dist_updates(only_security)
                 if all_updates:
-                    all_updates = list(set(updates1 + updates2))
+                    all_updates = updates1 + updates2
                     packages.append({
                         'pm': str(pm),
                         'type': pm.get_type(),
@@ -112,4 +122,4 @@ def main(argv):
 
 
 if __name__ == "__main__":
-    main(sys.argv[1:])
+    main()
